@@ -49,7 +49,10 @@ envvar_get_ipaddress <- function(x,
     transform = function(x) {
       ip <- suppressWarnings(ipaddress::as_ip_address(x))
       if (is.na(ip)) {
-        cli::cli_abort("{.val {x}} is not a valid IP address")
+        cli::cli_abort(
+          message = "{.val {x}} is not a valid IP address",
+          class = "envvar_invalid_ip_address"
+        )
       }
       ip
     },
